# Joking

Joking is a python library for getting random dad jokes and more kinds of jokes

![](https://img.shields.io/badge/build-Passing-green?style=for-the-badge) [![forthebadge](https://forthebadge.com/images/badges/gluten-free.svg)](https://forthebadge.com) [![forthebadge](https://forthebadge.com/images/badges/powered-by-electricity.svg)](https://forthebadge.com) ![](https://img.shields.io/badge/License-MIT-orange?style=for-the-badge) ![](https://bit.ly/3cTlr54) ![](https://tinyurl.com/badgesdhdh) ![](http://ForTheBadge.com/images/badges/made-with-python.svg) ![](https://tinyurl.com/emails83) ![PyPI - Downloads](https://tinyurl.com/smoler)

# Installation

you can install it by using the [pip](https://pip.pypa.io/en/stable/) package manager

```bash
pip install Joking
```

# How to Use

```python
Multiple_Jokes(i) #i is for the amount of dad jokes
```

```python
random_dad_joke() #prints out a random dad joke
```

```python
programming_joke() #prints a random programming joke
```

```python
random_joke() #prints a random joke
```

```python
sjoke() #Gets a specific joke using the joke id from https://icanhazdadjoke.com/
```


# How it works

It works by web scraping https://icanhazdadjoke.com/ and using version 2 of jokeapi.dev

# How to contribute

Start by going to https://github.com/Iwertyuiop123653/Joker then commit.